@@ -49,6 +49,8 @@ class BmpSaveOptionsData(object):
         'dml_effects_rendering_mode': 'str',
         'dml_rendering_mode': 'str',
         'file_name': 'str',
+        'flat_opc_xml_mapping_only': 'bool',
+        'iml_rendering_mode': 'str',
         'save_format': 'str',
         'update_created_time_property': 'bool',
         'update_fields': 'bool',
@@ -63,7 +65,6 @@ class BmpSaveOptionsData(object):
         'optimize_output': 'bool',
         'page_count': 'int',
         'page_index': 'int',
-        'graphics_quality_options': 'GraphicsQualityOptionsData',
         'horizontal_resolution': 'float',
         'image_brightness': 'float',
         'image_color_mode': 'str',
@@ -85,6 +86,8 @@ class BmpSaveOptionsData(object):
         'dml_effects_rendering_mode': 'DmlEffectsRenderingMode',
         'dml_rendering_mode': 'DmlRenderingMode',
         'file_name': 'FileName',
+        'flat_opc_xml_mapping_only': 'FlatOpcXmlMappingOnly',
+        'iml_rendering_mode': 'ImlRenderingMode',
         'save_format': 'SaveFormat',
         'update_created_time_property': 'UpdateCreatedTimeProperty',
         'update_fields': 'UpdateFields',
@@ -99,7 +102,6 @@ class BmpSaveOptionsData(object):
         'optimize_output': 'OptimizeOutput',
         'page_count': 'PageCount',
         'page_index': 'PageIndex',
-        'graphics_quality_options': 'GraphicsQualityOptions',
         'horizontal_resolution': 'HorizontalResolution',
         'image_brightness': 'ImageBrightness',
         'image_color_mode': 'ImageColorMode',
@@ -114,7 +116,7 @@ class BmpSaveOptionsData(object):
         'vertical_resolution': 'VerticalResolution'
     }
 
-    def __init__(self, allow_embedding_post_script_fonts=None, custom_time_zone_info_data=None, dml3_d_effects_rendering_mode=None, dml_effects_rendering_mode=None, dml_rendering_mode=None, file_name=None, save_format=None, update_created_time_property=None, update_fields=None, update_last_printed_property=None, update_last_saved_time_property=None, update_sdt_content=None, zip_output=None, color_mode=None, jpeg_quality=None, metafile_rendering_options=None, numeral_format=None, optimize_output=None, page_count=None, page_index=None, graphics_quality_options=None, horizontal_resolution=None, image_brightness=None, image_color_mode=None, image_contrast=None, paper_color=None, pixel_format=None, resolution=None, scale=None, use_anti_aliasing=None, use_gdi_emf_renderer=None, use_high_quality_rendering=None, vertical_resolution=None):  # noqa: E501
+    def __init__(self, allow_embedding_post_script_fonts=None, custom_time_zone_info_data=None, dml3_d_effects_rendering_mode=None, dml_effects_rendering_mode=None, dml_rendering_mode=None, file_name=None, flat_opc_xml_mapping_only=None, iml_rendering_mode=None, save_format=None, update_created_time_property=None, update_fields=None, update_last_printed_property=None, update_last_saved_time_property=None, update_sdt_content=None, zip_output=None, color_mode=None, jpeg_quality=None, metafile_rendering_options=None, numeral_format=None, optimize_output=None, page_count=None, page_index=None, horizontal_resolution=None, image_brightness=None, image_color_mode=None, image_contrast=None, paper_color=None, pixel_format=None, resolution=None, scale=None, use_anti_aliasing=None, use_gdi_emf_renderer=None, use_high_quality_rendering=None, vertical_resolution=None):  # noqa: E501
         """BmpSaveOptionsData - a model defined in Swagger"""  # noqa: E501
 
         self._allow_embedding_post_script_fonts = None
@@ -123,6 +125,8 @@ class BmpSaveOptionsData(object):
         self._dml_effects_rendering_mode = None
         self._dml_rendering_mode = None
         self._file_name = None
+        self._flat_opc_xml_mapping_only = None
+        self._iml_rendering_mode = None
         self._save_format = None
         self._update_created_time_property = None
         self._update_fields = None
@@ -137,7 +141,6 @@ class BmpSaveOptionsData(object):
         self._optimize_output = None
         self._page_count = None
         self._page_index = None
-        self._graphics_quality_options = None
         self._horizontal_resolution = None
         self._image_brightness = None
         self._image_color_mode = None
@@ -164,6 +167,10 @@ class BmpSaveOptionsData(object):
             self.dml_rendering_mode = dml_rendering_mode
         if file_name is not None:
             self.file_name = file_name
+        if flat_opc_xml_mapping_only is not None:
+            self.flat_opc_xml_mapping_only = flat_opc_xml_mapping_only
+        if iml_rendering_mode is not None:
+            self.iml_rendering_mode = iml_rendering_mode
         if save_format is not None:
             self.save_format = save_format
         if update_created_time_property is not None:
@@ -192,8 +199,6 @@ class BmpSaveOptionsData(object):
             self.page_count = page_count
         if page_index is not None:
             self.page_index = page_index
-        if graphics_quality_options is not None:
-            self.graphics_quality_options = graphics_quality_options
         if horizontal_resolution is not None:
             self.horizontal_resolution = horizontal_resolution
         if image_brightness is not None:
@@ -359,6 +364,50 @@ class BmpSaveOptionsData(object):
         """
         self._file_name = file_name
 
+    @property
+    def flat_opc_xml_mapping_only(self):
+        """Gets the flat_opc_xml_mapping_only of this BmpSaveOptionsData.  # noqa: E501
+
+        Gets or sets value determining which document formats are allowed to be mapped by Aspose.Words.Markup.StructuredDocumentTag.XmlMapping. By default only Aspose.Words.LoadFormat.FlatOpc document format is allowed to be mapped.  # noqa: E501
+
+        :return: The flat_opc_xml_mapping_only of this BmpSaveOptionsData.  # noqa: E501
+        :rtype: bool
+        """
+        return self._flat_opc_xml_mapping_only
+
+    @flat_opc_xml_mapping_only.setter
+    def flat_opc_xml_mapping_only(self, flat_opc_xml_mapping_only):
+        """Sets the flat_opc_xml_mapping_only of this BmpSaveOptionsData.
+
+        Gets or sets value determining which document formats are allowed to be mapped by Aspose.Words.Markup.StructuredDocumentTag.XmlMapping. By default only Aspose.Words.LoadFormat.FlatOpc document format is allowed to be mapped.  # noqa: E501
+
+        :param flat_opc_xml_mapping_only: The flat_opc_xml_mapping_only of this BmpSaveOptionsData.  # noqa: E501
+        :type: bool
+        """
+        self._flat_opc_xml_mapping_only = flat_opc_xml_mapping_only
+
+    @property
+    def iml_rendering_mode(self):
+        """Gets the iml_rendering_mode of this BmpSaveOptionsData.  # noqa: E501
+
+        Gets or sets the value determining how ink (InkML) objects are rendered.  # noqa: E501
+
+        :return: The iml_rendering_mode of this BmpSaveOptionsData.  # noqa: E501
+        :rtype: str
+        """
+        return self._iml_rendering_mode
+
+    @iml_rendering_mode.setter
+    def iml_rendering_mode(self, iml_rendering_mode):
+        """Sets the iml_rendering_mode of this BmpSaveOptionsData.
+
+        Gets or sets the value determining how ink (InkML) objects are rendered.  # noqa: E501
+
+        :param iml_rendering_mode: The iml_rendering_mode of this BmpSaveOptionsData.  # noqa: E501
+        :type: str
+        """
+        self._iml_rendering_mode = iml_rendering_mode
+
     @property
     def save_format(self):
         """Gets the save_format of this BmpSaveOptionsData.  # noqa: E501
@@ -667,28 +716,6 @@ class BmpSaveOptionsData(object):
         """
         self._page_index = page_index
 
-    @property
-    def graphics_quality_options(self):
-        """Gets the graphics_quality_options of this BmpSaveOptionsData.  # noqa: E501
-
-        Gets or sets the additional System.Drawing.Graphics quality options.  # noqa: E501
-
-        :return: The graphics_quality_options of this BmpSaveOptionsData.  # noqa: E501
-        :rtype: GraphicsQualityOptionsData
-        """
-        return self._graphics_quality_options
-
-    @graphics_quality_options.setter
-    def graphics_quality_options(self, graphics_quality_options):
-        """Sets the graphics_quality_options of this BmpSaveOptionsData.
-
-        Gets or sets the additional System.Drawing.Graphics quality options.  # noqa: E501
-
-        :param graphics_quality_options: The graphics_quality_options of this BmpSaveOptionsData.  # noqa: E501
-        :type: GraphicsQualityOptionsData
-        """
-        self._graphics_quality_options = graphics_quality_options
-
     @property
     def horizontal_resolution(self):
         """Gets the horizontal_resolution of this BmpSaveOptionsData.  # noqa: E501
