@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="border.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,6 +26,7 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
@@ -92,7 +93,7 @@ class Border(object):
     def link(self):
         """Gets the link of this Border.  # noqa: E501
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :return: The link of this Border.  # noqa: E501
         :rtype: WordsApiLink
@@ -103,7 +104,7 @@ class Border(object):
     def link(self, link):
         """Sets the link of this Border.
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :param link: The link of this Border.  # noqa: E501
         :type: WordsApiLink
@@ -166,7 +167,7 @@ class Border(object):
     def distance_from_text(self):
         """Gets the distance_from_text of this Border.  # noqa: E501
 
-        Gets or sets distance of the border from text or from the page edge in points.  # noqa: E501
+        Gets or sets the distance of the border from text or from the page edge in points.  # noqa: E501
 
         :return: The distance_from_text of this Border.  # noqa: E501
         :rtype: float
@@ -177,7 +178,7 @@ class Border(object):
     def distance_from_text(self, distance_from_text):
         """Sets the distance_from_text of this Border.
 
-        Gets or sets distance of the border from text or from the page edge in points.  # noqa: E501
+        Gets or sets the distance of the border from text or from the page edge in points.  # noqa: E501
 
         :param distance_from_text: The distance_from_text of this Border.  # noqa: E501
         :type: float
@@ -265,21 +266,25 @@ class Border(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -302,6 +307,8 @@ class Border(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
