@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="document_property.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,6 +26,7 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
@@ -77,7 +78,7 @@ class DocumentProperty(object):
     def link(self):
         """Gets the link of this DocumentProperty.  # noqa: E501
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :return: The link of this DocumentProperty.  # noqa: E501
         :rtype: WordsApiLink
@@ -88,7 +89,7 @@ class DocumentProperty(object):
     def link(self, link):
         """Sets the link of this DocumentProperty.
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :param link: The link of this DocumentProperty.  # noqa: E501
         :type: WordsApiLink
@@ -99,7 +100,7 @@ class DocumentProperty(object):
     def built_in(self):
         """Gets the built_in of this DocumentProperty.  # noqa: E501
 
-        Gets or sets a value indicating whether flag indicates whether the property is built-in or not. If true the property is built-in, if false the property is custom.  # noqa: E501
+        Gets or sets a value indicating whether the property is built-in or not. If true the property is built-in, if false the property is custom.  # noqa: E501
 
         :return: The built_in of this DocumentProperty.  # noqa: E501
         :rtype: bool
@@ -110,7 +111,7 @@ class DocumentProperty(object):
     def built_in(self, built_in):
         """Sets the built_in of this DocumentProperty.
 
-        Gets or sets a value indicating whether flag indicates whether the property is built-in or not. If true the property is built-in, if false the property is custom.  # noqa: E501
+        Gets or sets a value indicating whether the property is built-in or not. If true the property is built-in, if false the property is custom.  # noqa: E501
 
         :param built_in: The built_in of this DocumentProperty.  # noqa: E501
         :type: bool
@@ -121,7 +122,7 @@ class DocumentProperty(object):
     def name(self):
         """Gets the name of this DocumentProperty.  # noqa: E501
 
-        Gets or sets name of the document property.  # noqa: E501
+        Gets or sets the name of the document property.  # noqa: E501
 
         :return: The name of this DocumentProperty.  # noqa: E501
         :rtype: str
@@ -132,7 +133,7 @@ class DocumentProperty(object):
     def name(self, name):
         """Sets the name of this DocumentProperty.
 
-        Gets or sets name of the document property.  # noqa: E501
+        Gets or sets the name of the document property.  # noqa: E501
 
         :param name: The name of this DocumentProperty.  # noqa: E501
         :type: str
@@ -143,7 +144,7 @@ class DocumentProperty(object):
     def value(self):
         """Gets the value of this DocumentProperty.  # noqa: E501
 
-        Gets or sets string value of the document property.  # noqa: E501
+        Gets or sets the value of the document property.  # noqa: E501
 
         :return: The value of this DocumentProperty.  # noqa: E501
         :rtype: str
@@ -154,7 +155,7 @@ class DocumentProperty(object):
     def value(self, value):
         """Sets the value of this DocumentProperty.
 
-        Gets or sets string value of the document property.  # noqa: E501
+        Gets or sets the value of the document property.  # noqa: E501
 
         :param value: The value of this DocumentProperty.  # noqa: E501
         :type: str
@@ -168,21 +169,25 @@ class DocumentProperty(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -205,6 +210,8 @@ class DocumentProperty(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
