@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="drawing_object.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,12 +26,13 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
 
 class DrawingObject(object):
-    """Represents Drawing Object DTO.
+    """DTO container with a DrawingObject.
     """
 
     """
@@ -117,7 +118,7 @@ class DrawingObject(object):
     def link(self):
         """Gets the link of this DrawingObject.  # noqa: E501
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :return: The link of this DrawingObject.  # noqa: E501
         :rtype: WordsApiLink
@@ -128,7 +129,7 @@ class DrawingObject(object):
     def link(self, link):
         """Sets the link of this DrawingObject.
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :param link: The link of this DrawingObject.  # noqa: E501
         :type: WordsApiLink
@@ -139,7 +140,7 @@ class DrawingObject(object):
     def node_id(self):
         """Gets the node_id of this DrawingObject.  # noqa: E501
 
-        Gets or sets node id.  # noqa: E501
+        Gets or sets the node id.  # noqa: E501
 
         :return: The node_id of this DrawingObject.  # noqa: E501
         :rtype: str
@@ -150,7 +151,7 @@ class DrawingObject(object):
     def node_id(self, node_id):
         """Sets the node_id of this DrawingObject.
 
-        Gets or sets node id.  # noqa: E501
+        Gets or sets the node id.  # noqa: E501
 
         :param node_id: The node_id of this DrawingObject.  # noqa: E501
         :type: str
@@ -161,7 +162,7 @@ class DrawingObject(object):
     def height(self):
         """Gets the height of this DrawingObject.  # noqa: E501
 
-        Gets or sets height of the drawing object in points.  # noqa: E501
+        Gets or sets the height of the DrawingObject in points.  # noqa: E501
 
         :return: The height of this DrawingObject.  # noqa: E501
         :rtype: float
@@ -172,7 +173,7 @@ class DrawingObject(object):
     def height(self, height):
         """Sets the height of this DrawingObject.
 
-        Gets or sets height of the drawing object in points.  # noqa: E501
+        Gets or sets the height of the DrawingObject in points.  # noqa: E501
 
         :param height: The height of this DrawingObject.  # noqa: E501
         :type: float
@@ -183,7 +184,7 @@ class DrawingObject(object):
     def image_data_link(self):
         """Gets the image_data_link of this DrawingObject.  # noqa: E501
 
-        Gets or sets link to image data. Can be null if shape does not have an image.  # noqa: E501
+        Gets or sets the link to image data. Can be null if shape does not have an image.  # noqa: E501
 
         :return: The image_data_link of this DrawingObject.  # noqa: E501
         :rtype: WordsApiLink
@@ -194,7 +195,7 @@ class DrawingObject(object):
     def image_data_link(self, image_data_link):
         """Sets the image_data_link of this DrawingObject.
 
-        Gets or sets link to image data. Can be null if shape does not have an image.  # noqa: E501
+        Gets or sets the link to image data. Can be null if shape does not have an image.  # noqa: E501
 
         :param image_data_link: The image_data_link of this DrawingObject.  # noqa: E501
         :type: WordsApiLink
@@ -205,7 +206,7 @@ class DrawingObject(object):
     def left(self):
         """Gets the left of this DrawingObject.  # noqa: E501
 
-        Gets or sets distance in points from the origin to the left side of the image.  # noqa: E501
+        Gets or sets the distance in points from the origin to the left side of the image.  # noqa: E501
 
         :return: The left of this DrawingObject.  # noqa: E501
         :rtype: float
@@ -216,7 +217,7 @@ class DrawingObject(object):
     def left(self, left):
         """Sets the left of this DrawingObject.
 
-        Gets or sets distance in points from the origin to the left side of the image.  # noqa: E501
+        Gets or sets the distance in points from the origin to the left side of the image.  # noqa: E501
 
         :param left: The left of this DrawingObject.  # noqa: E501
         :type: float
@@ -227,7 +228,7 @@ class DrawingObject(object):
     def ole_data_link(self):
         """Gets the ole_data_link of this DrawingObject.  # noqa: E501
 
-        Gets or sets link to ole object. Can be null if shape does not have ole data.  # noqa: E501
+        Gets or sets the link to OLE object. Can be null if shape does not have OLE data.  # noqa: E501
 
         :return: The ole_data_link of this DrawingObject.  # noqa: E501
         :rtype: WordsApiLink
@@ -238,7 +239,7 @@ class DrawingObject(object):
     def ole_data_link(self, ole_data_link):
         """Sets the ole_data_link of this DrawingObject.
 
-        Gets or sets link to ole object. Can be null if shape does not have ole data.  # noqa: E501
+        Gets or sets the link to OLE object. Can be null if shape does not have OLE data.  # noqa: E501
 
         :param ole_data_link: The ole_data_link of this DrawingObject.  # noqa: E501
         :type: WordsApiLink
@@ -249,7 +250,7 @@ class DrawingObject(object):
     def relative_horizontal_position(self):
         """Gets the relative_horizontal_position of this DrawingObject.  # noqa: E501
 
-        Gets or sets specifies where the distance to the image is measured from.  # noqa: E501
+        Gets or sets the relative horizontal position, from which the distance to the image is measured.  # noqa: E501
 
         :return: The relative_horizontal_position of this DrawingObject.  # noqa: E501
         :rtype: str
@@ -260,7 +261,7 @@ class DrawingObject(object):
     def relative_horizontal_position(self, relative_horizontal_position):
         """Sets the relative_horizontal_position of this DrawingObject.
 
-        Gets or sets specifies where the distance to the image is measured from.  # noqa: E501
+        Gets or sets the relative horizontal position, from which the distance to the image is measured.  # noqa: E501
 
         :param relative_horizontal_position: The relative_horizontal_position of this DrawingObject.  # noqa: E501
         :type: str
@@ -279,7 +280,7 @@ class DrawingObject(object):
     def relative_vertical_position(self):
         """Gets the relative_vertical_position of this DrawingObject.  # noqa: E501
 
-        Gets or sets specifies where the distance to the image measured from.  # noqa: E501
+        Gets or sets the relative vertical position, from which the distance to the image is measured.  # noqa: E501
 
         :return: The relative_vertical_position of this DrawingObject.  # noqa: E501
         :rtype: str
@@ -290,7 +291,7 @@ class DrawingObject(object):
     def relative_vertical_position(self, relative_vertical_position):
         """Sets the relative_vertical_position of this DrawingObject.
 
-        Gets or sets specifies where the distance to the image measured from.  # noqa: E501
+        Gets or sets the relative vertical position, from which the distance to the image is measured.  # noqa: E501
 
         :param relative_vertical_position: The relative_vertical_position of this DrawingObject.  # noqa: E501
         :type: str
@@ -309,7 +310,7 @@ class DrawingObject(object):
     def render_links(self):
         """Gets the render_links of this DrawingObject.  # noqa: E501
 
-        Gets or sets a list of links that originate from this DrawingObjectDto.  # noqa: E501
+        Gets or sets the list of links that originate from this DrawingObjectDto.  # noqa: E501
 
         :return: The render_links of this DrawingObject.  # noqa: E501
         :rtype: list[WordsApiLink]
@@ -320,7 +321,7 @@ class DrawingObject(object):
     def render_links(self, render_links):
         """Sets the render_links of this DrawingObject.
 
-        Gets or sets a list of links that originate from this DrawingObjectDto.  # noqa: E501
+        Gets or sets the list of links that originate from this DrawingObjectDto.  # noqa: E501
 
         :param render_links: The render_links of this DrawingObject.  # noqa: E501
         :type: list[WordsApiLink]
@@ -331,7 +332,7 @@ class DrawingObject(object):
     def top(self):
         """Gets the top of this DrawingObject.  # noqa: E501
 
-        Gets or sets distance in points from the origin to the top side of the image.  # noqa: E501
+        Gets or sets the distance in points from the origin to the top side of the image.  # noqa: E501
 
         :return: The top of this DrawingObject.  # noqa: E501
         :rtype: float
@@ -342,7 +343,7 @@ class DrawingObject(object):
     def top(self, top):
         """Sets the top of this DrawingObject.
 
-        Gets or sets distance in points from the origin to the top side of the image.  # noqa: E501
+        Gets or sets the distance in points from the origin to the top side of the image.  # noqa: E501
 
         :param top: The top of this DrawingObject.  # noqa: E501
         :type: float
@@ -353,7 +354,7 @@ class DrawingObject(object):
     def width(self):
         """Gets the width of this DrawingObject.  # noqa: E501
 
-        Gets or sets width of the drawing objects in points.  # noqa: E501
+        Gets or sets the width of the DrawingObjects in points.  # noqa: E501
 
         :return: The width of this DrawingObject.  # noqa: E501
         :rtype: float
@@ -364,7 +365,7 @@ class DrawingObject(object):
     def width(self, width):
         """Sets the width of this DrawingObject.
 
-        Gets or sets width of the drawing objects in points.  # noqa: E501
+        Gets or sets the width of the DrawingObjects in points.  # noqa: E501
 
         :param width: The width of this DrawingObject.  # noqa: E501
         :type: float
@@ -375,7 +376,7 @@ class DrawingObject(object):
     def wrap_type(self):
         """Gets the wrap_type of this DrawingObject.  # noqa: E501
 
-        Gets or sets specifies how to wrap text around the image.  # noqa: E501
+        Gets or sets the option that controls how to wrap text around the image.  # noqa: E501
 
         :return: The wrap_type of this DrawingObject.  # noqa: E501
         :rtype: str
@@ -386,7 +387,7 @@ class DrawingObject(object):
     def wrap_type(self, wrap_type):
         """Sets the wrap_type of this DrawingObject.
 
-        Gets or sets specifies how to wrap text around the image.  # noqa: E501
+        Gets or sets the option that controls how to wrap text around the image.  # noqa: E501
 
         :param wrap_type: The wrap_type of this DrawingObject.  # noqa: E501
         :type: str
@@ -408,21 +409,25 @@ class DrawingObject(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -445,6 +450,8 @@ class DrawingObject(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
