@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="field_insert.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,6 +26,7 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
@@ -67,7 +68,7 @@ class FieldInsert(object):
     def field_code(self):
         """Gets the field_code of this FieldInsert.  # noqa: E501
 
-        Gets or sets field code.  # noqa: E501
+        Gets or sets the field code.  # noqa: E501
 
         :return: The field_code of this FieldInsert.  # noqa: E501
         :rtype: str
@@ -78,7 +79,7 @@ class FieldInsert(object):
     def field_code(self, field_code):
         """Sets the field_code of this FieldInsert.
 
-        Gets or sets field code.  # noqa: E501
+        Gets or sets the field code.  # noqa: E501
 
         :param field_code: The field_code of this FieldInsert.  # noqa: E501
         :type: str
@@ -89,7 +90,7 @@ class FieldInsert(object):
     def locale_id(self):
         """Gets the locale_id of this FieldInsert.  # noqa: E501
 
-        Gets or sets LCID of the field.  # noqa: E501
+        Gets or sets the LCID of the field.  # noqa: E501
 
         :return: The locale_id of this FieldInsert.  # noqa: E501
         :rtype: str
@@ -100,7 +101,7 @@ class FieldInsert(object):
     def locale_id(self, locale_id):
         """Sets the locale_id of this FieldInsert.
 
-        Gets or sets LCID of the field.  # noqa: E501
+        Gets or sets the LCID of the field.  # noqa: E501
 
         :param locale_id: The locale_id of this FieldInsert.  # noqa: E501
         :type: str
@@ -114,21 +115,25 @@ class FieldInsert(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -151,6 +156,8 @@ class FieldInsert(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
