@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="form_field_drop_down.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,6 +26,7 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
@@ -122,7 +123,7 @@ class FormFieldDropDown(object):
     def link(self):
         """Gets the link of this FormFieldDropDown.  # noqa: E501
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :return: The link of this FormFieldDropDown.  # noqa: E501
         :rtype: WordsApiLink
@@ -133,7 +134,7 @@ class FormFieldDropDown(object):
     def link(self, link):
         """Sets the link of this FormFieldDropDown.
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :param link: The link of this FormFieldDropDown.  # noqa: E501
         :type: WordsApiLink
@@ -144,7 +145,7 @@ class FormFieldDropDown(object):
     def node_id(self):
         """Gets the node_id of this FormFieldDropDown.  # noqa: E501
 
-        Gets or sets node id.  # noqa: E501
+        Gets or sets the node id.  # noqa: E501
 
         :return: The node_id of this FormFieldDropDown.  # noqa: E501
         :rtype: str
@@ -155,7 +156,7 @@ class FormFieldDropDown(object):
     def node_id(self, node_id):
         """Sets the node_id of this FormFieldDropDown.
 
-        Gets or sets node id.  # noqa: E501
+        Gets or sets the node id.  # noqa: E501
 
         :param node_id: The node_id of this FormFieldDropDown.  # noqa: E501
         :type: str
@@ -166,7 +167,7 @@ class FormFieldDropDown(object):
     def calculate_on_exit(self):
         """Gets the calculate_on_exit of this FormFieldDropDown.  # noqa: E501
 
-        Gets or sets true if references to the specified form field are automatically updated whenever the field is exited.  # noqa: E501
+        Gets or sets a value indicating whether references to the specified form field are automatically updated whenever the field is exited.  # noqa: E501
 
         :return: The calculate_on_exit of this FormFieldDropDown.  # noqa: E501
         :rtype: bool
@@ -177,7 +178,7 @@ class FormFieldDropDown(object):
     def calculate_on_exit(self, calculate_on_exit):
         """Sets the calculate_on_exit of this FormFieldDropDown.
 
-        Gets or sets true if references to the specified form field are automatically updated whenever the field is exited.  # noqa: E501
+        Gets or sets a value indicating whether references to the specified form field are automatically updated whenever the field is exited.  # noqa: E501
 
         :param calculate_on_exit: The calculate_on_exit of this FormFieldDropDown.  # noqa: E501
         :type: bool
@@ -188,7 +189,7 @@ class FormFieldDropDown(object):
     def enabled(self):
         """Gets the enabled of this FormFieldDropDown.  # noqa: E501
 
-        Gets or sets true if a form field is enabled.  # noqa: E501
+        Gets or sets a value indicating whether a form field is enabled.  # noqa: E501
 
         :return: The enabled of this FormFieldDropDown.  # noqa: E501
         :rtype: bool
@@ -199,7 +200,7 @@ class FormFieldDropDown(object):
     def enabled(self, enabled):
         """Sets the enabled of this FormFieldDropDown.
 
-        Gets or sets true if a form field is enabled.  # noqa: E501
+        Gets or sets a value indicating whether a form field is enabled.  # noqa: E501
 
         :param enabled: The enabled of this FormFieldDropDown.  # noqa: E501
         :type: bool
@@ -210,7 +211,7 @@ class FormFieldDropDown(object):
     def entry_macro(self):
         """Gets the entry_macro of this FormFieldDropDown.  # noqa: E501
 
-        Gets or sets returns or sets an entry macro name for the form field.  # noqa: E501
+        Gets or sets the entry macro name for the form field.  # noqa: E501
 
         :return: The entry_macro of this FormFieldDropDown.  # noqa: E501
         :rtype: str
@@ -221,7 +222,7 @@ class FormFieldDropDown(object):
     def entry_macro(self, entry_macro):
         """Sets the entry_macro of this FormFieldDropDown.
 
-        Gets or sets returns or sets an entry macro name for the form field.  # noqa: E501
+        Gets or sets the entry macro name for the form field.  # noqa: E501
 
         :param entry_macro: The entry_macro of this FormFieldDropDown.  # noqa: E501
         :type: str
@@ -232,7 +233,7 @@ class FormFieldDropDown(object):
     def exit_macro(self):
         """Gets the exit_macro of this FormFieldDropDown.  # noqa: E501
 
-        Gets or sets returns or sets an exit macro name for the form field.  # noqa: E501
+        Gets or sets the exit macro name for the form field.  # noqa: E501
 
         :return: The exit_macro of this FormFieldDropDown.  # noqa: E501
         :rtype: str
@@ -243,7 +244,7 @@ class FormFieldDropDown(object):
     def exit_macro(self, exit_macro):
         """Sets the exit_macro of this FormFieldDropDown.
 
-        Gets or sets returns or sets an exit macro name for the form field.  # noqa: E501
+        Gets or sets the exit macro name for the form field.  # noqa: E501
 
         :param exit_macro: The exit_macro of this FormFieldDropDown.  # noqa: E501
         :type: str
@@ -254,7 +255,7 @@ class FormFieldDropDown(object):
     def help_text(self):
         """Gets the help_text of this FormFieldDropDown.  # noqa: E501
 
-        Gets or sets returns or sets the text that's displayed in a message box when the form field has the focus and the user presses F1.  # noqa: E501
+        Gets or sets text, displayed in a message box when the form field has the focus and the user presses F1.  # noqa: E501
 
         :return: The help_text of this FormFieldDropDown.  # noqa: E501
         :rtype: str
@@ -265,7 +266,7 @@ class FormFieldDropDown(object):
     def help_text(self, help_text):
         """Sets the help_text of this FormFieldDropDown.
 
-        Gets or sets returns or sets the text that's displayed in a message box when the form field has the focus and the user presses F1.  # noqa: E501
+        Gets or sets text, displayed in a message box when the form field has the focus and the user presses F1.  # noqa: E501
 
         :param help_text: The help_text of this FormFieldDropDown.  # noqa: E501
         :type: str
@@ -298,7 +299,7 @@ class FormFieldDropDown(object):
     def own_help(self):
         """Gets the own_help of this FormFieldDropDown.  # noqa: E501
 
-        Gets or sets specifies the source of the text that's displayed in a message box when a form field has the focus and the user presses F1.  # noqa: E501
+        Gets or sets a value indicating whether the source of the text that's displayed in a message box when a form field has the focus and the user presses F1.  # noqa: E501
 
         :return: The own_help of this FormFieldDropDown.  # noqa: E501
         :rtype: bool
@@ -309,7 +310,7 @@ class FormFieldDropDown(object):
     def own_help(self, own_help):
         """Sets the own_help of this FormFieldDropDown.
 
-        Gets or sets specifies the source of the text that's displayed in a message box when a form field has the focus and the user presses F1.  # noqa: E501
+        Gets or sets a value indicating whether the source of the text that's displayed in a message box when a form field has the focus and the user presses F1.  # noqa: E501
 
         :param own_help: The own_help of this FormFieldDropDown.  # noqa: E501
         :type: bool
@@ -320,7 +321,7 @@ class FormFieldDropDown(object):
     def own_status(self):
         """Gets the own_status of this FormFieldDropDown.  # noqa: E501
 
-        Gets or sets specifies the source of the text that's displayed in the status bar when a form field has the focus.  # noqa: E501
+        Gets or sets a value indicating whether the source of the text that's displayed in the status bar when a form field has the focus.  # noqa: E501
 
         :return: The own_status of this FormFieldDropDown.  # noqa: E501
         :rtype: bool
@@ -331,7 +332,7 @@ class FormFieldDropDown(object):
     def own_status(self, own_status):
         """Sets the own_status of this FormFieldDropDown.
 
-        Gets or sets specifies the source of the text that's displayed in the status bar when a form field has the focus.  # noqa: E501
+        Gets or sets a value indicating whether the source of the text that's displayed in the status bar when a form field has the focus.  # noqa: E501
 
         :param own_status: The own_status of this FormFieldDropDown.  # noqa: E501
         :type: bool
@@ -342,7 +343,7 @@ class FormFieldDropDown(object):
     def status_text(self):
         """Gets the status_text of this FormFieldDropDown.  # noqa: E501
 
-        Gets or sets returns or sets the text that's displayed in the status bar when a form field has the focus.  # noqa: E501
+        Gets or sets text, displayed in the status bar when a form field has the focus.  # noqa: E501
 
         :return: The status_text of this FormFieldDropDown.  # noqa: E501
         :rtype: str
@@ -353,7 +354,7 @@ class FormFieldDropDown(object):
     def status_text(self, status_text):
         """Sets the status_text of this FormFieldDropDown.
 
-        Gets or sets returns or sets the text that's displayed in the status bar when a form field has the focus.  # noqa: E501
+        Gets or sets text, displayed in the status bar when a form field has the focus.  # noqa: E501
 
         :param status_text: The status_text of this FormFieldDropDown.  # noqa: E501
         :type: str
@@ -364,7 +365,7 @@ class FormFieldDropDown(object):
     def drop_down_items(self):
         """Gets the drop_down_items of this FormFieldDropDown.  # noqa: E501
 
-        Gets or sets provides access to the items of a dropdown form field.  # noqa: E501
+        Gets or sets the items array of a dropdown form field.  # noqa: E501
 
         :return: The drop_down_items of this FormFieldDropDown.  # noqa: E501
         :rtype: list[str]
@@ -375,7 +376,7 @@ class FormFieldDropDown(object):
     def drop_down_items(self, drop_down_items):
         """Sets the drop_down_items of this FormFieldDropDown.
 
-        Gets or sets provides access to the items of a dropdown form field.  # noqa: E501
+        Gets or sets the items array of a dropdown form field.  # noqa: E501
 
         :param drop_down_items: The drop_down_items of this FormFieldDropDown.  # noqa: E501
         :type: list[str]
@@ -411,21 +412,25 @@ class FormFieldDropDown(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -448,6 +453,8 @@ class FormFieldDropDown(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
