@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="modification_operation_result.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,6 +26,7 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
@@ -67,7 +68,7 @@ class ModificationOperationResult(object):
     def dest(self):
         """Gets the dest of this ModificationOperationResult.  # noqa: E501
 
-        Gets or sets link to the dest document (result of the modification operation).  # noqa: E501
+        Gets or sets the link to the dest document (result of the modification operation).  # noqa: E501
 
         :return: The dest of this ModificationOperationResult.  # noqa: E501
         :rtype: FileLink
@@ -78,7 +79,7 @@ class ModificationOperationResult(object):
     def dest(self, dest):
         """Sets the dest of this ModificationOperationResult.
 
-        Gets or sets link to the dest document (result of the modification operation).  # noqa: E501
+        Gets or sets the link to the dest document (result of the modification operation).  # noqa: E501
 
         :param dest: The dest of this ModificationOperationResult.  # noqa: E501
         :type: FileLink
@@ -89,7 +90,7 @@ class ModificationOperationResult(object):
     def source(self):
         """Gets the source of this ModificationOperationResult.  # noqa: E501
 
-        Gets or sets link to the source document (source for the modification operation).  # noqa: E501
+        Gets or sets the link to the source document (source for the modification operation).  # noqa: E501
 
         :return: The source of this ModificationOperationResult.  # noqa: E501
         :rtype: FileLink
@@ -100,7 +101,7 @@ class ModificationOperationResult(object):
     def source(self, source):
         """Sets the source of this ModificationOperationResult.
 
-        Gets or sets link to the source document (source for the modification operation).  # noqa: E501
+        Gets or sets the link to the source document (source for the modification operation).  # noqa: E501
 
         :param source: The source of this ModificationOperationResult.  # noqa: E501
         :type: FileLink
@@ -114,21 +115,25 @@ class ModificationOperationResult(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -151,6 +156,8 @@ class ModificationOperationResult(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
