@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="search_response.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,12 +26,13 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
 
 class SearchResponse(object):
-    """This response should be returned by the service when handling: GET https://api.aspose.cloud/v4.0/words/Test.doc/search.
+    """The REST response with a regular expression pattern and a collection of search results.
     """
 
     """
@@ -72,7 +73,7 @@ class SearchResponse(object):
     def request_id(self):
         """Gets the request_id of this SearchResponse.  # noqa: E501
 
-        Gets or sets request Id.  # noqa: E501
+        Gets or sets the request Id.  # noqa: E501
 
         :return: The request_id of this SearchResponse.  # noqa: E501
         :rtype: str
@@ -83,7 +84,7 @@ class SearchResponse(object):
     def request_id(self, request_id):
         """Sets the request_id of this SearchResponse.
 
-        Gets or sets request Id.  # noqa: E501
+        Gets or sets the request Id.  # noqa: E501
 
         :param request_id: The request_id of this SearchResponse.  # noqa: E501
         :type: str
@@ -94,7 +95,7 @@ class SearchResponse(object):
     def searching_pattern(self):
         """Gets the searching_pattern of this SearchResponse.  # noqa: E501
 
-        Gets or sets a regular expression pattern used to find matches.  # noqa: E501
+        Gets or sets the regular expression pattern used to find matches.  # noqa: E501
 
         :return: The searching_pattern of this SearchResponse.  # noqa: E501
         :rtype: str
@@ -105,7 +106,7 @@ class SearchResponse(object):
     def searching_pattern(self, searching_pattern):
         """Sets the searching_pattern of this SearchResponse.
 
-        Gets or sets a regular expression pattern used to find matches.  # noqa: E501
+        Gets or sets the regular expression pattern used to find matches.  # noqa: E501
 
         :param searching_pattern: The searching_pattern of this SearchResponse.  # noqa: E501
         :type: str
@@ -116,7 +117,7 @@ class SearchResponse(object):
     def search_results(self):
         """Gets the search_results of this SearchResponse.  # noqa: E501
 
-        Gets or sets collection of search results.  # noqa: E501
+        Gets or sets the collection of search results.  # noqa: E501
 
         :return: The search_results of this SearchResponse.  # noqa: E501
         :rtype: SearchResultsCollection
@@ -127,7 +128,7 @@ class SearchResponse(object):
     def search_results(self, search_results):
         """Sets the search_results of this SearchResponse.
 
-        Gets or sets collection of search results.  # noqa: E501
+        Gets or sets the collection of search results.  # noqa: E501
 
         :param search_results: The search_results of this SearchResponse.  # noqa: E501
         :type: SearchResultsCollection
@@ -141,21 +142,25 @@ class SearchResponse(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -178,6 +183,8 @@ class SearchResponse(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
