@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="split_document_response.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,12 +26,13 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
 
 class SplitDocumentResponse(object):
-    """This response should be returned by the service when handling:  POST /{name}/split .
+    """The REST response with a result of document splitting.
     """
 
     """
@@ -67,7 +68,7 @@ class SplitDocumentResponse(object):
     def request_id(self):
         """Gets the request_id of this SplitDocumentResponse.  # noqa: E501
 
-        Gets or sets request Id.  # noqa: E501
+        Gets or sets the request Id.  # noqa: E501
 
         :return: The request_id of this SplitDocumentResponse.  # noqa: E501
         :rtype: str
@@ -78,7 +79,7 @@ class SplitDocumentResponse(object):
     def request_id(self, request_id):
         """Sets the request_id of this SplitDocumentResponse.
 
-        Gets or sets request Id.  # noqa: E501
+        Gets or sets the request Id.  # noqa: E501
 
         :param request_id: The request_id of this SplitDocumentResponse.  # noqa: E501
         :type: str
@@ -89,7 +90,7 @@ class SplitDocumentResponse(object):
     def split_result(self):
         """Gets the split_result of this SplitDocumentResponse.  # noqa: E501
 
-        Gets or sets resylt of splitting document.  # noqa: E501
+        Gets or sets the result of document splitting.  # noqa: E501
 
         :return: The split_result of this SplitDocumentResponse.  # noqa: E501
         :rtype: SplitDocumentResult
@@ -100,7 +101,7 @@ class SplitDocumentResponse(object):
     def split_result(self, split_result):
         """Sets the split_result of this SplitDocumentResponse.
 
-        Gets or sets resylt of splitting document.  # noqa: E501
+        Gets or sets the result of document splitting.  # noqa: E501
 
         :param split_result: The split_result of this SplitDocumentResponse.  # noqa: E501
         :type: SplitDocumentResult
@@ -114,21 +115,25 @@ class SplitDocumentResponse(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -151,6 +156,8 @@ class SplitDocumentResponse(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
