@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="table.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,12 +26,13 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
 
 class Table(object):
-    """Table element.
+    """DTO container with a table element.
     """
 
     """
@@ -77,7 +78,7 @@ class Table(object):
     def link(self):
         """Gets the link of this Table.  # noqa: E501
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :return: The link of this Table.  # noqa: E501
         :rtype: WordsApiLink
@@ -88,7 +89,7 @@ class Table(object):
     def link(self, link):
         """Sets the link of this Table.
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :param link: The link of this Table.  # noqa: E501
         :type: WordsApiLink
@@ -99,7 +100,7 @@ class Table(object):
     def node_id(self):
         """Gets the node_id of this Table.  # noqa: E501
 
-        Gets or sets node id.  # noqa: E501
+        Gets or sets the node id.  # noqa: E501
 
         :return: The node_id of this Table.  # noqa: E501
         :rtype: str
@@ -110,7 +111,7 @@ class Table(object):
     def node_id(self, node_id):
         """Sets the node_id of this Table.
 
-        Gets or sets node id.  # noqa: E501
+        Gets or sets the node id.  # noqa: E501
 
         :param node_id: The node_id of this Table.  # noqa: E501
         :type: str
@@ -143,7 +144,7 @@ class Table(object):
     def table_row_list(self):
         """Gets the table_row_list of this Table.  # noqa: E501
 
-        Gets or sets collection of table's rows.  # noqa: E501
+        Gets or sets the collection of table's rows.  # noqa: E501
 
         :return: The table_row_list of this Table.  # noqa: E501
         :rtype: list[TableRow]
@@ -154,7 +155,7 @@ class Table(object):
     def table_row_list(self, table_row_list):
         """Sets the table_row_list of this Table.
 
-        Gets or sets collection of table's rows.  # noqa: E501
+        Gets or sets the collection of table's rows.  # noqa: E501
 
         :param table_row_list: The table_row_list of this Table.  # noqa: E501
         :type: list[TableRow]
@@ -168,21 +169,25 @@ class Table(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -205,6 +210,8 @@ class Table(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
