@@ -22,10 +22,12 @@ from test.api.font.test_font import TestFont
 from test.api.footnote.test_footnote import TestFootnote
 from test.api.header_footer.test_header_footer import TestHeaderFooter
 from test.api.hyperlink.test_hyperlink import TestHyperlink
+from test.api.info.test_info import TestInfo
 from test.api.lists.test_lists import TestLists
 from test.api.macros.test_macros import TestMacros
 from test.api.mail_merge.test_execute_mail_merge import TestExecuteMailMerge
 from test.api.mail_merge.test_execute_template import TestExecuteTemplate
+from test.api.mail_merge.test_execute_template_with_field_options import TestExecuteTemplateWithFieldOptions
 from test.api.mail_merge.test_mail_merge_fileds import TestMailMergeFileds
 from test.api.math_object.test_math_object import TestMathObject
 from test.api.page_setup.test_page_setup import TestPageSetup
@@ -44,4 +46,5 @@ from test.api.watermark.test_watermark import TestWatermark
 from test.test_url_encode import TestUrlEncode
 from test.test_readme import TestReadme
 from test.test_batch import TestBatch
-from test.test_examples import TestExamples
\ No newline at end of file
+from test.test_examples import TestExamples
+from test.test_doc_with_password import TestDocWithPassword
\ No newline at end of file
